@@ -1,7 +1,6 @@
 # model parameters ---------------------
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.logitor <- function(model,
                                      ci = 0.95,
@@ -25,17 +24,14 @@ model_parameters.logitor <- function(model,
 }
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.poissonirr <- model_parameters.logitor
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.negbinirr <- model_parameters.logitor
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.poissonmfx <- function(model,
                                         ci = 0.95,
@@ -45,6 +41,8 @@ model_parameters.poissonmfx <- function(model,
                                         standardize = NULL,
                                         exponentiate = FALSE,
                                         p_adjust = NULL,
+                                        keep = NULL,
+                                        drop = NULL,
                                         verbose = TRUE,
                                         ...) {
   component <- match.arg(component)
@@ -58,6 +56,9 @@ model_parameters.poissonmfx <- function(model,
     exponentiate = exponentiate,
     component = component,
     p_adjust = p_adjust,
+    keep_parameters = keep,
+    drop_parameters = drop,
+    verbose = verbose,
     ...
   )
 
@@ -66,17 +67,14 @@ model_parameters.poissonmfx <- function(model,
 }
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.logitmfx <- model_parameters.poissonmfx
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.probitmfx <- model_parameters.poissonmfx
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.negbinmfx <- model_parameters.poissonmfx
 
@@ -118,6 +116,8 @@ model_parameters.betamfx <- function(model,
                                      standardize = NULL,
                                      exponentiate = FALSE,
                                      p_adjust = NULL,
+                                     keep = NULL,
+                                     drop = NULL,
                                      verbose = TRUE,
                                      ...) {
   component <- match.arg(component)
@@ -131,6 +131,9 @@ model_parameters.betamfx <- function(model,
     exponentiate = exponentiate,
     component = component,
     p_adjust = p_adjust,
+    keep_parameters = keep,
+    drop_parameters = drop,
+    verbose = verbose,
     ...
   )
 
